==> savane-1.0.8+2.tar.gz: savane-1.0.8+2/backend/mail/sv_mailman.pl <==
#!/usr/bin/perl
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: sv_mailman.pl,v 1.13 2005/06/30 16:33:51 toddy Exp $
#
#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#
#
# FIXME: check the drawback explanation below.


use strict;
use Getopt::Long;
use Savane;
use POSIX qw(strftime);

my $script = "sv_mailman";
my $logfile = "/var/log/sv_database2system.log";
my $lockfile = "/var/run/sv_database2system.lock";

# Import
our $sys_mail_domain;
our $sys_cron_mailman;

# Preconfigure
my $getopt;
my $help;
my $debug;
my $cron;

eval {
    $getopt = GetOptions("debug" => \$debug,
			 "cron" => \$cron,
			 "help" => \$help);
};

if($help || !$getopt) {
    print STDERR <<EOF;
Usage: $0 [--user=<user> --password=<password>] [--help] [--verbose]

Create with mailman shell command a list for each mailing list found in
the database with status set to 1. 
It will change the status of the created list to 5.

      --help                   Show this help and exit
      --cron                   Option to set when including this script
                               in a crontab


Author: yeupou\@gnu.org
EOF
 exit(1);
}

# Test if we should run, according to conffile
exit if ($cron && ! $sys_cron_mailman);


sub Escape {
    my $data = $_[0];
    $data =~ s/\'/\\\'/g;
    return $data;
}


# Log: Starting logging
open (LOG, ">>$logfile");
print LOG strftime "[$script] %c - starting\n", localtime;


# Locks: There are several sv_db2sys scripts but they should not run
#        concurrently.  So we add a lock
if (-e $lockfile) {
    print LOG "[$script] There's a lock ($lockfile), exiting\n";
    print LOG "[$script] ------------------------------------------------------\n";
    die "There's a lock ($lockfile), exiting";
}
system("touch", $lockfile);


foreach my $line (GetDB("mail_group_list", 
			"status='1' OR status='0'",
			"group_list_id,list_name,is_public,password,list_admin,description")) {
    chomp($line);
    my ($id, $name, $is_public, $password, $admin, $description) = split(",", $line);
    $admin = GetUserName($admin)."\@".$sys_mail_domain;

    # Create the list.
    system("/usr/sbin/newlist",
	   "-q",
	   $name,
	   $admin,
	   $password);
    print LOG strftime "[$script] %c - List $name <$admin> newlist.\n", localtime;
    
    # Configure the list.
    
    # Avoid race conditions
    system("/bin/rm", "-rf", "/tmp/mmcfg");
    mkdir("/tmp/mmcfg", 0700)
	or die "Unable to create /tmp/mmcfg safely. Exiting";

    open(TMPCFG, "> /tmp/mmcfg/mmcfg");
    # Always set description
    print TMPCFG "description = '".Escape($description)."'\n";
    # mailman is not useful to fight spam, in fact being forced to use
    # it's interface instead of having a spamassassin doing the job
    # can be seen as a pain.
    print TMPCFG "require_explicit_destination = 0\n";
    # Do not advertise, hide archives, require approval if private list
    print TMPCFG "archive_private = 1\n" unless $is_public;
    print TMPCFG "advertised = 0\n" unless $is_public;
    print TMPCFG "subscribe_policy = 3\n" unless $is_public;
    # Always give access to the member list only to list admins
    print TMPCFG "private_roster = 2\n";
    # Set the message limit size reasonnably big
    ## Set in mm_cfg.py
    ## print TMPCFG "max_message_size = 10240\n";
    close(TMPCFG);
    system("/usr/sbin/config_list",
	   "--inputfile",
	   "/tmp/mmcfg/mmcfg",
	   $name);
    print LOG strftime "[$script] %c - List $name <$admin> config_list.\n", localtime;

    # Send a mail giving the password 
    my $mail = "Hello,

You requested the creation of the list $name at $sys_mail_domain.

The list administrator password of the mailing list $name is:
                   $password 

You are advised to change the password, and to avoid at any cost using 
a password you use for others important account, as mailman does not
really provide security for these list passwords.

Currently no convenient way to get back your list administrator password
is implemented, so it would be best if you make sure to remember your
list password :-)

Regards,";

    MailSend("", $admin, "Mailman list $name", $mail);
    print LOG strftime "[$script] %c - Mail sent to $admin for list $name.\n", localtime;
    
    # Drawback1: I run here an SQL command to reset the status and to get
    # the admin login for each list. I could be resources consuming, however
    # I think we cannot expect this to be too heavy, not so many list should
    # be created everyday.
    # This scalability issue should be kept in mind, however.
    # Drawback2: currently this script only create list, does not
    # update them. This should be fixed in one way or another.

    SetDBSettings("mail_group_list",
		  "list_name='$name'",
		  "status='5'");
    print LOG strftime "[$script] %c - List $name <$admin> created.\n", localtime;
    
}


# Final exit
print LOG strftime "[$script] %c - work finished\n", localtime;
print LOG "[$script] ------------------------------------------------------\n";
unlink($lockfile, "/tmp/mmcfg/mmcfg");
system("/bin/rm", "-rf", "/tmp/mmcfg");

# END

==> savane-1.3+2.tar.gz: savane-1.3+2/backend/mail/sv_mailman.pl <==
#!/usr/bin/perl
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: sv_mailman.pl 4740 2005-09-13 09:39:08Z yeupou $
#
#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#
#
# FIXME: check the drawback explanation below.


use strict;
use Getopt::Long;
use Savane;
use POSIX qw(strftime);
use File::Temp qw(tempfile tempdir);

my $script = "sv_mailman";
my $logfile = "/var/log/sv_database2system.log";
my $lockfile = "/var/run/sv_database2system.lock";

# Import
our $sys_mail_domain;
our $sys_cron_mailman;

# Preconfigure
my $getopt;
my $help;
my $debug;
my $cron;

eval {
    $getopt = GetOptions("debug" => \$debug,
			 "cron" => \$cron,
			 "help" => \$help);
};

if($help || !$getopt) {
    print STDERR <<EOF;
Usage: $0 [--user=<user> --password=<password>] [--help] [--verbose]

Create with mailman shell command a list for each mailing list found in
the database with status set to 1. 
It will change the status of the created list to 5.

      --help                   Show this help and exit
      --cron                   Option to set when including this script
                               in a crontab


Author: yeupou\@gnu.org
EOF
 exit(1);
}

# Test if we should run, according to conffile
exit if ($cron && ! $sys_cron_mailman);


sub Escape {
    my $data = $_[0];
    $data =~ s/\'/\\\'/g;
    return $data;
}


# Log: Starting logging
open (LOG, ">>$logfile");
print LOG strftime "[$script] %c - starting\n", localtime;


# Locks: There are several sv_db2sys scripts but they should not run
#        concurrently.  So we add a lock
if (-e $lockfile) {
    print LOG "[$script] There's a lock ($lockfile), exiting\n";
    print LOG "[$script] ------------------------------------------------------\n";
    die "There's a lock ($lockfile), exiting";
}
system("touch", $lockfile);


foreach my $line (GetDB("mail_group_list", 
			"status='1' OR status='0'",
			"group_list_id,list_name,is_public,password,list_admin,description")) {
    chomp($line);
    my ($id, $name, $is_public, $password, $admin, $description) = split(",", $line);
    $admin = GetUserName($admin)."\@".$sys_mail_domain;

    # Create the list.
    system("/usr/sbin/newlist",
	   "-q",
	   $name,
	   $admin,
	   $password);
    print LOG strftime "[$script] %c - List $name <$admin> newlist.\n", localtime;
    
    # Configure the list.
    my ($tmpcfgfh, $tmpcfg) = tempfile(UNLINK => 1);

    # Always set description
    print $tmpcfgfh "description = '".Escape($description)."'\n";
    # mailman is not useful to fight spam, in fact being forced to use
    # it's interface instead of having a spamassassin doing the job
    # can be seen as a pain.
    print $tmpcfgfh "require_explicit_destination = 0\n";
    # Do not advertise, hide archives, require approval if private list
    print $tmpcfgfh "archive_private = 1\n" unless $is_public;
    print $tmpcfgfh "advertised = 0\n" unless $is_public;
    print $tmpcfgfh "subscribe_policy = 3\n" unless $is_public;
    # Always give access to the member list only to list admins
    print $tmpcfgfh "private_roster = 2\n";
    # Set the message limit size reasonnably big
    ## Set in mm_cfg.py
    ## print TMPCFG "max_message_size = 10240\n";
    close($tmpcfgfh);
    system("/usr/sbin/config_list",
	   "--inputfile",
	   $tmpcfg,
	   $name);
    print LOG strftime "[$script] %c - List $name <$admin> config_list.\n", localtime;

    # Send a mail giving the password 
    my $mail = "Hello,

You requested the creation of the list $name at $sys_mail_domain.

The list administrator password of the mailing list $name is:
                   $password 

You are advised to change the password, and to avoid at any cost using 
a password you use for others important account, as mailman does not
really provide security for these list passwords.

Currently no convenient way to get back your list administrator password
is implemented, so it would be best if you make sure to remember your
list password :-)

Regards,";

    MailSend("", $admin, "Mailman list $name", $mail);
    print LOG strftime "[$script] %c - Mail sent to $admin for list $name.\n", localtime;
    
    # Drawback1: I run here an SQL command to reset the status and to get
    # the admin login for each list. I could be resources consuming, however
    # I think we cannot expect this to be too heavy, not so many list should
    # be created everyday.
    # This scalability issue should be kept in mind, however.
    # Drawback2: currently this script only create list, does not
    # update them. This should be fixed in one way or another.

    SetDBSettings("mail_group_list",
		  "list_name='$name'",
		  "status='5'");
    print LOG strftime "[$script] %c - List $name <$admin> created.\n", localtime;
    
}


# Final exit
print LOG strftime "[$script] %c - work finished\n", localtime;
print LOG "[$script] ------------------------------------------------------\n";
unlink($lockfile);

# END
